@@ -3,11 +3,13 @@
 # Internal Libraries
 from datetime import timedelta
 
+# External Libraries
+import av
+
 # Included Libraries
 from auto_editor.utils.func import get_new_length
 
 def display_length(secs):
-    # display length
     if(secs < 0):
         return '-' + str(timedelta(seconds=round(abs(secs))))
     return str(timedelta(seconds=round(secs)))
@@ -18,13 +20,13 @@ def time_frame(title, frames, fps):
     print('{}: {} secs ({})'.format(title, in_sec, minutes))
 
 
-def preview(inp, chunks, speeds, log):
+def preview(inp, chunks, log):
     fps = 30 if inp.fps is None else float(inp.fps)
 
     log.conwrite('')
 
     old_length = chunks[-1][1] / fps
-    new_length = get_new_length(chunks, speeds, fps)
+    new_length = get_new_length(chunks, fps)
 
     diff = new_length - old_length
 
@@ -41,10 +43,9 @@ def preview(inp, chunks, speeds, log):
     cut_lens = []
     clip_lens = []
     for chunk in chunks:
-        state = chunk[2]
-        if(speeds[state] != 99999):
+        if(chunk[2] != 99999):
             clips += 1
-            leng = (chunk[1] - chunk[0]) / speeds[state]
+            leng = (chunk[1] - chunk[0]) / chunk[2]
             clip_lens.append(leng)
         else:
             cuts += 1
@@ -52,21 +53,20 @@ def preview(inp, chunks, speeds, log):
             cut_lens.append(leng)
 
     print('clips: {}'.format(clips))
-    if(len(clip_lens) == 1):
-        time_frame(' - clip length', clip_lens[0], fps)
+    if(len(clip_lens) < 2):
+        time_frame(' - clip length', sum(clip_lens), fps)
     else:
         time_frame(' - smallest', min(clip_lens), fps)
         time_frame(' - largest', max(clip_lens), fps)
         time_frame(' - average', sum(clip_lens) / len(clip_lens), fps)
-        print('cuts: {}'.format(cuts))
 
-    if(cut_lens != []):
-        if(len(cut_lens) == 1):
-            time_frame(' - cut length', cut_lens[0], fps)
-        else:
-            time_frame(' - smallest', min(cut_lens), fps)
-            time_frame(' - largest', max(cut_lens), fps)
-            time_frame(' - average', sum(cut_lens) / len(cut_lens), fps)
-        print('')
+    print('cuts: {}'.format(cuts))
+    if(len(cut_lens) < 2):
+        time_frame(' - cut length', sum(cut_lens), fps)
+    else:
+        time_frame(' - smallest', min(cut_lens), fps)
+        time_frame(' - largest', max(cut_lens), fps)
+        time_frame(' - average', sum(cut_lens) / len(cut_lens), fps)
+    print('')
 
     log.debug('Chunks: {}'.format(chunks))
