@@ -28,32 +28,22 @@ class Wrapper:
         return self._fh.read(buf_size)
 
 
-def render_av(ffmpeg, track, inp, args, chunks, fps, has_vfr, progress, effects, rules,
-    temp, log):
+def render_av(ffmpeg, track, inp, args, chunks, fps, progress, effects, rules, temp, log):
     try:
         import av
     except ImportError:
         log.error("av python module not installed. Run 'pip install av'")
 
-    total_frames = chunks[len(chunks) - 1][1]
+    if(chunks[-1][2] == 99999):
+        chunks.pop()
+
+    total_frames = chunks[-1][1]
     progress.start(total_frames, 'Creating new video')
 
     container = av.open(inp.path, 'r')
     pix_fmt = container.streams.video[track].pix_fmt
 
-    if(has_vfr):
-        # Create a cfr stream on stdout.
-        cmd = ['-i', inp.path, '-map', f'0:v:{track}', '-vf', f'fps=fps={fps}', '-r',
-            str(fps), '-vsync', '1', '-f', 'matroska']
-        if(not pix_fmt_allowed(pix_fmt)):
-            pix_fmt = 'yuv420p'
-            cmd.extend(['-pix_fmt', pix_fmt])
-
-        cmd.extend(['-vcodec', 'rawvideo', 'pipe:1'])
-
-        wrapper = Wrapper(ffmpeg.Popen(cmd).stdout)
-        container = av.open(wrapper, 'r')
-    elif(not pix_fmt_allowed(pix_fmt)):
+    if(not pix_fmt_allowed(pix_fmt)):
         pix_fmt = 'yuv420p'
         cmd = ['-i', inp.path, '-map', f'0:v:{track}', '-f', 'matroska', '-pix_fmt', pix_fmt,
             '-vcodec', 'rawvideo', 'pipe:1']
@@ -73,7 +63,6 @@ def render_av(ffmpeg, track, inp, args, chunks, fps, has_vfr, progress, effects,
     if(args.scale != 1):
         apply_video_later = False
 
-    log.debug(f'pix_fmt: {pix_fmt}')
     log.debug(f'apply video quality settings now: {not apply_video_later}')
 
     video_stream = container.streams.video[track]
@@ -113,17 +102,20 @@ def render_av(ffmpeg, track, inp, args, chunks, fps, has_vfr, progress, effects,
     chunk = chunks.pop(0)
 
     try:
-        for index, frame in enumerate(container.decode(video_stream)):
-            if(len(chunks) > 0 and index-1 >= chunk[1]):
-                chunk = chunks.pop(0)
-                if(len(chunks) == 0 and chunk[2] == 99999):
+        for frame in container.decode(video_stream):
+            index = int(frame.time * fps)
+
+            if index > chunk[1]:
+                if chunks:
+                    chunk = chunks.pop(0)
+                else:
                     break
 
-            if(chunk[2] != 99999):
+            if chunk[2] != 99999:
                 input_equavalent += (1 / chunk[2])
 
             while input_equavalent > output_equavalent:
-                if(index in effects.sheet):
+                if index in effects.sheet:
                     frame = effects.apply(index, frame, pix_fmt)
 
                 in_bytes = frame.to_ndarray().tobytes()
@@ -150,9 +142,8 @@ def render_av(ffmpeg, track, inp, args, chunks, fps, has_vfr, progress, effects,
         check_errors = ffmpeg.pipe(cmd)
         if('Error' in check_errors or 'failed' in check_errors):
             if('-allow_sw 1' in check_errors):
-                # Add "-allow_sw 1" to command.
-                cmd.insert(-1, '1')
                 cmd.insert(-1, '-allow_sw')
+                cmd.insert(-1, '1')
             # Run again to show errors even if it might not work.
             ffmpeg.run(cmd)
 
